==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/hompybutton.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "hompybutton.h"

HompyButton::HompyButton(QWidget* parent,const QString& iname,long tcol/*=-1*/):
	ShapeButton(parent, iname, tcol)
{
	listViewItem_ = 0;
	connect(this, SIGNAL(clicked()), this, SLOT(clickedThis()) );
}

void HompyButton::clickedThis()
{
	emit gotoHompy(listViewItem());
}

#include "hompybutton.moc"

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/hompybutton.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "hompybutton.h"

HompyButton::HompyButton(QWidget* parent,const QString& iname,long tcol/*=-1*/):
        ShapeButton(parent, iname, tcol) {
    listViewItem_ = 0;
    connect(this, SIGNAL(clicked()), this, SLOT(clickedThis()) );
}

void HompyButton::clickedThis() {
    emit gotoHompy(listViewItem());
}

#include "hompybutton.moc"
